This is the amazing Minigrep that’s going to take the world by storm
Structs
Functions
- run
- This function is the primary runner for Minigrep, which receives a Config object to know what to do
- search
- This function searches for a string in a given string
- search_
case_ insensitive - This function searches for a string in a given string, without regard to the case of either